@@ -34,6 +34,7 @@ var (
 	readmeNames      = []string{"README.md", "README", "Readme.md", "Readme", "readme.md", "readme"}
 	configFile       string
 	pager            bool
+	tui              bool
 	style            string
 	width            uint
 	showAllFiles     bool
@@ -141,16 +142,10 @@ func sourceFromArg(arg string) (*source, error) {
 	return &source{r, u}, err
 }
 
-func validateOptions(cmd *cobra.Command) error {
-	// grab config values from Viper
-	width = viper.GetUint("width")
-	mouse = viper.GetBool("mouse")
-	pager = viper.GetBool("pager")
-	preserveNewLines = viper.GetBool("preserveNewLines")
-
-	// validate the glamour style
-	style = viper.GetString("style")
-	if style != styles.AutoStyle && styles.DefaultStyles[style] == nil {
+// validateStyle checks if the style is a default style, if not, checks that
+// the custom style exists.
+func validateStyle(style string) error {
+	if style != "auto" && styles.DefaultStyles[style] == nil {
 		style = utils.ExpandPath(style)
 		if _, err := os.Stat(style); errors.Is(err, fs.ErrNotExist) {
 			return fmt.Errorf("Specified style does not exist: %s", style)
@@ -158,6 +153,27 @@ func validateOptions(cmd *cobra.Command) error {
 			return err
 		}
 	}
+	return nil
+}
+
+func validateOptions(cmd *cobra.Command) error {
+	// grab config values from Viper
+	width = viper.GetUint("width")
+	mouse = viper.GetBool("mouse")
+	pager = viper.GetBool("pager")
+	tui = viper.GetBool("tui")
+	showAllFiles = viper.GetBool("all")
+	preserveNewLines = viper.GetBool("preserveNewLines")
+
+	if pager && tui {
+		return errors.New("glow: cannot use both pager and tui")
+	}
+
+	// validate the glamour style
+	style = viper.GetString("style")
+	if err := validateStyle(style); err != nil {
+		return err
+	}
 
 	isTerminal := term.IsTerminal(int(os.Stdout.Fd()))
 	// We want to use a special no-TTY style, when stdout is not a terminal
@@ -210,7 +226,7 @@ func execute(cmd *cobra.Command, args []string) error {
 	switch len(args) {
 	// TUI running on cwd
 	case 0:
-		return runTUI("")
+		return runTUI("", "")
 
 	// TUI with possible dir argument
 	case 1:
@@ -220,7 +236,7 @@ func execute(cmd *cobra.Command, args []string) error {
 		if err == nil && info.IsDir() {
 			p, err := filepath.Abs(args[0])
 			if err == nil {
-				return runTUI(p)
+				return runTUI(p, "")
 			}
 		}
 		fallthrough
@@ -277,19 +293,20 @@ func executeCLI(cmd *cobra.Command, src *source, w io.Writer) error {
 		return err
 	}
 
-	s := string(b)
+	content := string(b)
 	ext := filepath.Ext(src.URL)
 	if isCode {
-		s = utils.WrapCodeBlock(string(b), ext)
+		content = utils.WrapCodeBlock(string(b), ext)
 	}
 
-	out, err := r.Render(s)
+	out, err := r.Render(content)
 	if err != nil {
 		return err
 	}
 
 	// display
-	if pager || cmd.Flags().Changed("pager") {
+	switch {
+	case pager || cmd.Flags().Changed("pager"):
 		pagerCmd := os.Getenv("PAGER")
 		if pagerCmd == "" {
 			pagerCmd = "less -r"
@@ -300,30 +317,35 @@ func executeCLI(cmd *cobra.Command, src *source, w io.Writer) error {
 		c.Stdin = strings.NewReader(out)
 		c.Stdout = os.Stdout
 		return c.Run()
+	case tui || cmd.Flags().Changed("tui"):
+		return runTUI(src.URL, content)
+	default:
+		_, err = fmt.Fprint(w, out)
+		return err
 	}
-
-	_, err = fmt.Fprint(w, out)
-	return err
 }
 
-func runTUI(workingDirectory string) error {
+func runTUI(path string, content string) error {
 	// Read environment to get debugging stuff
 	cfg, err := env.ParseAs[ui.Config]()
 	if err != nil {
 		return fmt.Errorf("error parsing config: %v", err)
 	}
 
-	cfg.WorkingDirectory = workingDirectory
+	// use style set in env, or auto if unset
+	if err := validateStyle(cfg.GlamourStyle); err != nil {
+		cfg.GlamourStyle = style
+	}
 
+	cfg.Path = path
 	cfg.ShowAllFiles = showAllFiles
 	cfg.ShowLineNumbers = showLineNumbers
 	cfg.GlamourMaxWidth = width
-	cfg.GlamourStyle = style
 	cfg.EnableMouse = mouse
 	cfg.PreserveNewLines = preserveNewLines
 
 	// Run Bubble Tea program
-	if _, err := ui.NewProgram(cfg).Run(); err != nil {
+	if _, err := ui.NewProgram(cfg, content).Run(); err != nil {
 		return err
 	}
 
@@ -358,6 +380,7 @@ func init() {
 	// "Glow Classic" cli arguments
 	rootCmd.PersistentFlags().StringVar(&configFile, "config", "", fmt.Sprintf("config file (default %s)", viper.GetViper().ConfigFileUsed()))
 	rootCmd.Flags().BoolVarP(&pager, "pager", "p", false, "display with pager")
+	rootCmd.Flags().BoolVarP(&tui, "tui", "t", false, "display with tui")
 	rootCmd.Flags().StringVarP(&style, "style", "s", styles.AutoStyle, "style name or JSON path")
 	rootCmd.Flags().UintVarP(&width, "width", "w", 0, "word-wrap at width (set to 0 to disable)")
 	rootCmd.Flags().BoolVarP(&showAllFiles, "all", "a", false, "show system files and directories (TUI-mode only)")
@@ -367,16 +390,19 @@ func init() {
 	_ = rootCmd.Flags().MarkHidden("mouse")
 
 	// Config bindings
+	_ = viper.BindPFlag("pager", rootCmd.Flags().Lookup("pager"))
+	_ = viper.BindPFlag("tui", rootCmd.Flags().Lookup("tui"))
 	_ = viper.BindPFlag("style", rootCmd.Flags().Lookup("style"))
 	_ = viper.BindPFlag("width", rootCmd.Flags().Lookup("width"))
 	_ = viper.BindPFlag("debug", rootCmd.Flags().Lookup("debug"))
 	_ = viper.BindPFlag("mouse", rootCmd.Flags().Lookup("mouse"))
 	_ = viper.BindPFlag("preserveNewLines", rootCmd.Flags().Lookup("preserve-new-lines"))
 	_ = viper.BindPFlag("showLineNumbers", rootCmd.Flags().Lookup("line-numbers"))
-	_ = viper.BindPFlag("showAllFiles", rootCmd.Flags().Lookup("all"))
+	_ = viper.BindPFlag("all", rootCmd.Flags().Lookup("all"))
 
 	viper.SetDefault("style", styles.AutoStyle)
 	viper.SetDefault("width", 0)
+	viper.SetDefault("all", true)
 
 	rootCmd.AddCommand(configCmd, manCmd)
 }
