@@ -100,7 +100,6 @@ func (m stashModel) helpView() (string, int) {
 	}
 
 	var (
-		isEditable    bool
 		navHelp       []string
 		filterHelp    []string
 		selectionHelp []string
@@ -130,13 +129,6 @@ func (m stashModel) helpView() (string, int) {
 		filterHelp = []string{"/", "edit search", "esc", "clear filter"}
 	} else {
 		filterHelp = []string{"/", "find"}
-		if m.stashFullyLoaded {
-			filterHelp = append(filterHelp, "t", "team filter")
-		}
-	}
-
-	if isEditable {
-		editHelp = []string{"e", "edit"}
 	}
 
 	// If there are errors
@@ -145,6 +137,7 @@ func (m stashModel) helpView() (string, int) {
 	}
 
 	appHelp = append(appHelp, "r", "refresh")
+	appHelp = append(appHelp, "e", "edit")
 	appHelp = append(appHelp, "q", "quit")
 
 	// Detailed help
