@@ -7,11 +7,9 @@ import (
 	"strings"
 	"time"
 
-	"github.com/charmbracelet/bubbles/list"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/glamour/styles"
 	"github.com/charmbracelet/glow/v2/utils"
-	"github.com/charmbracelet/lipgloss"
 	"github.com/charmbracelet/log"
 	"github.com/muesli/gitcha"
 	te "github.com/muesli/termenv"
@@ -31,7 +29,7 @@ var (
 )
 
 // NewProgram returns a new Tea program.
-func NewProgram(cfg Config) *tea.Program {
+func NewProgram(cfg Config, content string) *tea.Program {
 	log.Debug(
 		"Starting glow",
 		"high_perf_pager",
@@ -45,7 +43,7 @@ func NewProgram(cfg Config) *tea.Program {
 	if cfg.EnableMouse {
 		opts = append(opts, tea.WithMouseCellMotion())
 	}
-	m := newModel(cfg)
+	m := newModel(cfg, content)
 	return tea.NewProgram(m, opts...)
 }
 
@@ -131,7 +129,7 @@ func (m *model) unloadDocument() []tea.Cmd {
 	return batch
 }
 
-func newModel(cfg Config) tea.Model {
+func newModel(cfg Config, content string) tea.Model {
 	initSections()
 
 	if cfg.GlamourStyle == styles.AutoStyle {
@@ -142,29 +140,64 @@ func newModel(cfg Config) tea.Model {
 		}
 	}
 
-	teamList := list.New([]list.Item{}, list.NewDefaultDelegate(), 0, 0)
-	teamList.Styles.Title = lipgloss.NewStyle().Foreground(yellowGreen)
-	teamList.SetStatusBarItemName("team", "teams")
-	teamList.SetShowHelp(true)
-
-	// We use the team list status message as a permanent placeholder.
-	teamList.StatusMessageLifetime = time.Hour
-
 	common := commonModel{
 		cfg: cfg,
 	}
 
-	return model{
+	m := model{
 		common: &common,
 		state:  stateShowStash,
 		pager:  newPagerModel(&common),
 		stash:  newStashModel(&common),
 	}
+
+	path := cfg.Path
+	if path == "" && content != "" {
+		m.state = stateShowDocument
+		m.pager.currentDocument = markdown{Body: content}
+		return m
+	}
+
+	if path == "" {
+		path = "."
+	}
+	info, err := os.Stat(path)
+	if err != nil {
+		log.Error("unable to stat file", "file", path, "error", err)
+		m.fatalErr = err
+		return m
+	}
+	if info.IsDir() {
+		m.state = stateShowStash
+	} else {
+		cwd, _ := os.Getwd()
+		m.state = stateShowDocument
+		m.pager.currentDocument = markdown{
+			localPath: path,
+			Note:      stripAbsolutePath(path, cwd),
+			Modtime:   info.ModTime(),
+		}
+	}
+
+	return m
 }
 
 func (m model) Init() tea.Cmd {
 	cmds := []tea.Cmd{m.stash.spinner.Tick}
-	cmds = append(cmds, findLocalFiles(*m.common))
+
+	switch m.state {
+	case stateShowStash:
+		cmds = append(cmds, findLocalFiles(*m.common))
+	case stateShowDocument:
+		content, err := os.ReadFile(m.common.cfg.Path)
+		if err != nil {
+			log.Error("unable to read file", "file", m.common.cfg.Path, "error", err)
+			return func() tea.Msg { return errMsg{err} }
+		}
+		body := string(utils.RemoveFrontmatter(content))
+		cmds = append(cmds, renderWithGlamour(m.pager, body))
+	}
+
 	return tea.Batch(cmds...)
 }
 
@@ -187,7 +220,13 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 				return m, tea.Batch(batch...)
 			}
 		case "r":
+			var cmd tea.Cmd
 			if m.state == stateShowStash {
+				// pass through all keys if we're editing the filter
+				if m.stash.filterState == filtering {
+					m.stash, cmd = m.stash.update(msg)
+					return m, cmd
+				}
 				m.stash.markdowns = nil
 				return m, m.Init()
 			}
@@ -318,7 +357,7 @@ func findLocalFiles(m commonModel) tea.Cmd {
 	return func() tea.Msg {
 		log.Info("findLocalFiles")
 		var (
-			cwd = m.cfg.WorkingDirectory
+			cwd = m.cfg.Path
 			err error
 		)
 
@@ -384,17 +423,17 @@ func waitForStatusMessageTimeout(appCtx applicationContext, t *time.Timer) tea.C
 // document. Note that we could be doing things like checking if the file is
 // a directory, but we trust that gitcha has already done that.
 func localFileToMarkdown(cwd string, res gitcha.SearchResult) *markdown {
-	md := &markdown{
+	return &markdown{
 		localPath: res.Path,
 		Note:      stripAbsolutePath(res.Path, cwd),
 		Modtime:   res.Info.ModTime(),
 	}
-
-	return md
 }
 
 func stripAbsolutePath(fullPath, cwd string) string {
-	return strings.ReplaceAll(fullPath, cwd+string(os.PathSeparator), "")
+	fp, _ := filepath.EvalSymlinks(fullPath)
+	cp, _ := filepath.EvalSymlinks(cwd)
+	return strings.ReplaceAll(fp, cp+string(os.PathSeparator), "")
 }
 
 // Lightweight version of reflow's indent function.
